@@ -1,4 +1,4 @@
-## Copyright (C) 2006, 2007 David Bateman
+## Copyright (C) 2006-2012 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -18,8 +18,8 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} secd (@var{x})
-## Compute the secant of an angle in degrees.
-## @seealso{sec, cscd, sind, cosd}
+## Compute the secant for each element of @var{x} in degrees.
+## @seealso{asecd, sec}
 ## @end deftypefn
 
 ## Author: David Bateman <dbateman@free.fr>
