@@ -1,4 +1,4 @@
-## Copyright (C) 1999, 2000, 2007, 2009 Kai Habel
+## Copyright (C) 1999-2012 Kai Habel
 ##
 ## This file is part of Octave.
 ##
@@ -17,31 +17,33 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} copper (@var{n})
-## Create color colormap.  This colormap is black to a light copper tone.
-## The argument @var{n} should be a scalar.  If it
-## is omitted, the length of the current colormap or 64 is assumed.
+## @deftypefn  {Function File} {@var{map} =} copper ()
+## @deftypefnx {Function File} {@var{map} =} copper (@var{n})
+## Create color colormap.  This colormap varies from black to
+## a light copper tone.
+## The argument @var{n} must be a scalar.
+## If unspecified, the length of the current colormap, or 64, is used.
 ## @seealso{colormap}
 ## @end deftypefn
 
 ## Author:  Kai Habel <kai.habel@gmx.de>
 
-function map = copper (number)
+function map = copper (n)
 
   if (nargin == 0)
-    number = rows (colormap);
+    n = rows (colormap);
   elseif (nargin == 1)
-    if (! isscalar (number))
+    if (! isscalar (n))
       error ("copper: argument must be a scalar");
     endif
   else
     print_usage ();
   endif
 
-  if (number == 1)
-    map = [0, 0, 0];  
-  elseif (number > 1)
-    x = linspace (0, 1, number)';
+  if (n == 1)
+    map = [0, 0, 0];
+  elseif (n > 1)
+    x = linspace (0, 1, n)';
     r = (x < 4/5) .* (5/4 * x) + (x >= 4/5);
     g = 4/5 * x;
     b = 1/2 * x;
@@ -51,3 +53,10 @@ function map = copper (number)
   endif
 
 endfunction
+
+%!demo
+%! ## Show the 'copper' colormap as an image
+%! image (1:64, linspace (0, 1, 64), repmat (1:64, 64, 1)')
+%! axis ([1, 64, 0, 1], "ticy", "xy")
+%! colormap (copper (64))
+
