@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 2004 John W. Eaton
+Copyright (C) 2004-2012 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -40,7 +39,9 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include "ov-bool.h"
 #include "ov-bool-mat.h"
 #include "ov-scalar.h"
+#include "ov-float.h"
 #include "ov-re-mat.h"
+#include "ov-flt-re-mat.h"
 #include "ov-str-mat.h"
 #include "ov-typeinfo.h"
 #include "op-int.h"
@@ -134,12 +135,32 @@ OCTAVE_DOUBLE_INT_CONCAT_FN (int8)
 OCTAVE_DOUBLE_INT_CONCAT_FN (int16)
 OCTAVE_DOUBLE_INT_CONCAT_FN (int32)
 OCTAVE_DOUBLE_INT_CONCAT_FN (int64)
-	      	   
+
 OCTAVE_DOUBLE_INT_CONCAT_FN (uint8)
 OCTAVE_DOUBLE_INT_CONCAT_FN (uint16)
 OCTAVE_DOUBLE_INT_CONCAT_FN (uint32)
 OCTAVE_DOUBLE_INT_CONCAT_FN (uint64)
 
+OCTAVE_INT_FLOAT_CONCAT_FN (int8)
+OCTAVE_INT_FLOAT_CONCAT_FN (int16)
+OCTAVE_INT_FLOAT_CONCAT_FN (int32)
+OCTAVE_INT_FLOAT_CONCAT_FN (int64)
+
+OCTAVE_INT_FLOAT_CONCAT_FN (uint8)
+OCTAVE_INT_FLOAT_CONCAT_FN (uint16)
+OCTAVE_INT_FLOAT_CONCAT_FN (uint32)
+OCTAVE_INT_FLOAT_CONCAT_FN (uint64)
+
+OCTAVE_FLOAT_INT_CONCAT_FN (int8)
+OCTAVE_FLOAT_INT_CONCAT_FN (int16)
+OCTAVE_FLOAT_INT_CONCAT_FN (int32)
+OCTAVE_FLOAT_INT_CONCAT_FN (int64)
+
+OCTAVE_FLOAT_INT_CONCAT_FN (uint8)
+OCTAVE_FLOAT_INT_CONCAT_FN (uint16)
+OCTAVE_FLOAT_INT_CONCAT_FN (uint32)
+OCTAVE_FLOAT_INT_CONCAT_FN (uint64)
+
 OCTAVE_INT_CHAR_CONCAT_FN (int8)
 OCTAVE_INT_CHAR_CONCAT_FN (int16)
 OCTAVE_INT_CHAR_CONCAT_FN (int32)
@@ -154,7 +175,7 @@ OCTAVE_CHAR_INT_CONCAT_FN (int8)
 OCTAVE_CHAR_INT_CONCAT_FN (int16)
 OCTAVE_CHAR_INT_CONCAT_FN (int32)
 OCTAVE_CHAR_INT_CONCAT_FN (int64)
-	      	   
+
 OCTAVE_CHAR_INT_CONCAT_FN (uint8)
 OCTAVE_CHAR_INT_CONCAT_FN (uint16)
 OCTAVE_CHAR_INT_CONCAT_FN (uint32)
@@ -255,6 +276,26 @@ install_int_concat_ops (void)
   OCTAVE_INSTALL_DOUBLE_INT_CONCAT_FN (uint32);
   OCTAVE_INSTALL_DOUBLE_INT_CONCAT_FN (uint64);
 
+  OCTAVE_INSTALL_INT_FLOAT_CONCAT_FN (int8);
+  OCTAVE_INSTALL_INT_FLOAT_CONCAT_FN (int16);
+  OCTAVE_INSTALL_INT_FLOAT_CONCAT_FN (int32);
+  OCTAVE_INSTALL_INT_FLOAT_CONCAT_FN (int64);
+
+  OCTAVE_INSTALL_INT_FLOAT_CONCAT_FN (uint8);
+  OCTAVE_INSTALL_INT_FLOAT_CONCAT_FN (uint16);
+  OCTAVE_INSTALL_INT_FLOAT_CONCAT_FN (uint32);
+  OCTAVE_INSTALL_INT_FLOAT_CONCAT_FN (uint64);
+
+  OCTAVE_INSTALL_FLOAT_INT_CONCAT_FN (int8);
+  OCTAVE_INSTALL_FLOAT_INT_CONCAT_FN (int16);
+  OCTAVE_INSTALL_FLOAT_INT_CONCAT_FN (int32);
+  OCTAVE_INSTALL_FLOAT_INT_CONCAT_FN (int64);
+
+  OCTAVE_INSTALL_FLOAT_INT_CONCAT_FN (uint8);
+  OCTAVE_INSTALL_FLOAT_INT_CONCAT_FN (uint16);
+  OCTAVE_INSTALL_FLOAT_INT_CONCAT_FN (uint32);
+  OCTAVE_INSTALL_FLOAT_INT_CONCAT_FN (uint64);
+
   OCTAVE_INSTALL_INT_CHAR_CONCAT_FN (int8);
   OCTAVE_INSTALL_INT_CHAR_CONCAT_FN (int16);
   OCTAVE_INSTALL_INT_CHAR_CONCAT_FN (int32);
@@ -275,9 +316,3 @@ install_int_concat_ops (void)
   OCTAVE_INSTALL_CHAR_INT_CONCAT_FN (uint32);
   OCTAVE_INSTALL_CHAR_INT_CONCAT_FN (uint64);
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
