@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1996-2012 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,16 +15,15 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
 #if !defined (octave_octave_iostream_h)
 #define octave_octave_iostream_h 1
 
-#include <iostream>
+#include <iosfwd>
 
 #include "oct-stream.h"
 
@@ -34,9 +33,9 @@ octave_base_iostream : public octave_base_stream
 public:
 
   octave_base_iostream (const std::string& n = std::string (),
-			std::ios::openmode m = std::ios::in|std::ios::out,
-			oct_mach_info::float_format ff
-			  = oct_mach_info::native_float_format ())
+                        std::ios::openmode m = std::ios::in|std::ios::out,
+                        oct_mach_info::float_format ff
+                          = oct_mach_info::native_float_format ())
     : octave_base_stream (m, ff), nm (n) { }
 
   // Position a stream at OFFSET relative to ORIGIN.
@@ -81,7 +80,7 @@ public:
 
   octave_istream (std::istream *arg = 0, const std::string& n = std::string ())
     : octave_base_iostream (n, std::ios::in,
-			    oct_mach_info::native_float_format ()),
+                            oct_mach_info::native_float_format ()),
       is (arg)
   { }
 
@@ -120,7 +119,7 @@ public:
 
   octave_ostream (std::ostream *arg, const std::string& n = std::string ())
     : octave_base_iostream (n, std::ios::out,
-			    oct_mach_info::native_float_format ()),
+                            oct_mach_info::native_float_format ()),
       os (arg)
   { }
 
@@ -153,9 +152,3 @@ private:
 };
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
