@@ -1,6 +1,7 @@
 /*
 
-Copyright (C) 2004, 2005, 2006, 2007, 2008 John W. Eaton
+Copyright (C) 2004-2012 John W. Eaton
+Copyright (C) 2010 VZLU Prague
 
 This file is part of Octave.
 
@@ -52,7 +53,7 @@ public:
   OCTAVE_VALUE_INT_MATRIX_T (const intNDArray<OCTAVE_INT_T>& nda)
     : octave_base_int_matrix<intNDArray<OCTAVE_INT_T> > (nda) { }
 
-  OCTAVE_VALUE_INT_MATRIX_T (const ArrayN<OCTAVE_INT_T>& nda)
+  OCTAVE_VALUE_INT_MATRIX_T (const Array<OCTAVE_INT_T>& nda)
     : octave_base_int_matrix<intNDArray<OCTAVE_INT_T> >
         (intNDArray<OCTAVE_INT_T> (nda)) { }
 
@@ -68,47 +69,33 @@ public:
 
   bool is_integer_type (void) const { return true; }
 
-private:
-
-  template <class IM>
-  IM convert_gripe () const
-    {
-      typedef typename IM::element_type dest_el_type;
-      typedef intNDArray<OCTAVE_INT_T>::element_type src_el_type;
-      dest_el_type::clear_conv_flag ();
-      IM retval (matrix);
-      if (dest_el_type::get_trunc_flag ())
-	gripe_truncated_conversion (src_el_type::type_name (),
-				    dest_el_type::type_name ());
-      dest_el_type::clear_conv_flag ();
-      return retval;
-    }
+  builtin_type_t builtin_type (void) const { return OCTAVE_INT_BTYP; }
 
 public:
 
   int8NDArray
-  int8_array_value (void) const { return convert_gripe<int8NDArray> (); }
+  int8_array_value (void) const { return int8NDArray (matrix); }
 
   int16NDArray
-  int16_array_value (void) const { return convert_gripe<int16NDArray> (); }
+  int16_array_value (void) const { return int16NDArray (matrix); }
 
   int32NDArray
-  int32_array_value (void) const { return convert_gripe<int32NDArray> (); }
+  int32_array_value (void) const { return int32NDArray (matrix); }
 
   int64NDArray
-  int64_array_value (void) const { return convert_gripe<int64NDArray> (); }
+  int64_array_value (void) const { return int64NDArray (matrix); }
 
   uint8NDArray
-  uint8_array_value (void) const { return convert_gripe<uint8NDArray> (); }
+  uint8_array_value (void) const { return uint8NDArray (matrix); }
 
   uint16NDArray
-  uint16_array_value (void) const { return convert_gripe<uint16NDArray> (); }
+  uint16_array_value (void) const { return uint16NDArray (matrix); }
 
   uint32NDArray
-  uint32_array_value (void) const { return convert_gripe<uint32NDArray> (); }
+  uint32_array_value (void) const { return uint32NDArray (matrix); }
 
   uint64NDArray
-  uint64_array_value (void) const { return convert_gripe<uint64NDArray> (); }
+  uint64_array_value (void) const { return uint64NDArray (matrix); }
 
   double
   double_value (bool = false) const
@@ -116,17 +103,17 @@ public:
       double retval = lo_ieee_nan_value ();
 
       if (numel () > 0)
-	{
-	  gripe_implicit_conversion ("Octave:array-as-scalar",
-				     type_name (), "real scalar");
+        {
+          gripe_implicit_conversion ("Octave:array-as-scalar",
+                                     type_name (), "real scalar");
 
-	  retval = matrix(0).double_value ();
-	}
+          retval = matrix(0).double_value ();
+        }
       else
-	gripe_invalid_conversion (type_name (), "real scalar");
+        gripe_invalid_conversion (type_name (), "real scalar");
 
       return retval;
-      
+
     }
 
   float
@@ -135,17 +122,17 @@ public:
       float retval = lo_ieee_float_nan_value ();
 
       if (numel () > 0)
-	{
-	  gripe_implicit_conversion ("Octave:array-as-scalar",
-				     type_name (), "real scalar");
+        {
+          gripe_implicit_conversion ("Octave:array-as-scalar",
+                                     type_name (), "real scalar");
 
-	  retval = matrix(0).float_value ();
-	}
+          retval = matrix(0).float_value ();
+        }
       else
-	gripe_invalid_conversion (type_name (), "real scalar");
+        gripe_invalid_conversion (type_name (), "real scalar");
 
       return retval;
-      
+
     }
 
   double scalar_value (bool = false) const { return double_value (); }
@@ -158,15 +145,15 @@ public:
       Matrix retval;
       dim_vector dv = dims ();
       if (dv.length () > 2)
-	error ("invalid conversion of %s to Matrix", type_name().c_str ());
+        error ("invalid conversion of %s to Matrix", type_name().c_str ());
       else
-	{
-	  retval = Matrix (dv(0), dv(1));
-	  double *vec = retval.fortran_vec ();
-	  octave_idx_type nel = matrix.numel ();
-	  for (octave_idx_type i = 0; i < nel; i++)
-	    vec[i] = matrix(i).double_value ();
-	}
+        {
+          retval = Matrix (dv(0), dv(1));
+          double *vec = retval.fortran_vec ();
+          octave_idx_type nel = matrix.numel ();
+          for (octave_idx_type i = 0; i < nel; i++)
+            vec[i] = matrix(i).double_value ();
+        }
       return retval;
     }
 
@@ -176,15 +163,15 @@ public:
       FloatMatrix retval;
       dim_vector dv = dims ();
       if (dv.length () > 2)
-	error ("invalid conversion of %s to FloatMatrix", type_name().c_str ());
+        error ("invalid conversion of %s to FloatMatrix", type_name().c_str ());
       else
-	{
-	  retval = FloatMatrix (dv(0), dv(1));
-	  float *vec = retval.fortran_vec ();
-	  octave_idx_type nel = matrix.numel ();
-	  for (octave_idx_type i = 0; i < nel; i++)
-	    vec[i] = matrix(i).float_value ();
-	}
+        {
+          retval = FloatMatrix (dv(0), dv(1));
+          float *vec = retval.fortran_vec ();
+          octave_idx_type nel = matrix.numel ();
+          for (octave_idx_type i = 0; i < nel; i++)
+            vec[i] = matrix(i).float_value ();
+        }
       return retval;
     }
 
@@ -194,15 +181,15 @@ public:
       ComplexMatrix retval;
       dim_vector dv = dims();
       if (dv.length () > 2)
-	error ("invalid conversion of %s to Matrix", type_name().c_str ());
+        error ("invalid conversion of %s to Matrix", type_name().c_str ());
       else
-	{
-	  retval = ComplexMatrix (dv(0), dv(1));
-	  Complex *vec = retval.fortran_vec ();
-	  octave_idx_type nel = matrix.numel ();
-	  for (octave_idx_type i = 0; i < nel; i++)
-	    vec[i] = Complex (matrix(i).double_value ());
-	}
+        {
+          retval = ComplexMatrix (dv(0), dv(1));
+          Complex *vec = retval.fortran_vec ();
+          octave_idx_type nel = matrix.numel ();
+          for (octave_idx_type i = 0; i < nel; i++)
+            vec[i] = Complex (matrix(i).double_value ());
+        }
       return retval;
     }
 
@@ -212,22 +199,22 @@ public:
       FloatComplexMatrix retval;
       dim_vector dv = dims();
       if (dv.length () > 2)
-	error ("invalid conversion of %s to FloatMatrix", type_name().c_str ());
+        error ("invalid conversion of %s to FloatMatrix", type_name().c_str ());
       else
-	{
-	  retval = FloatComplexMatrix (dv(0), dv(1));
-	  FloatComplex *vec = retval.fortran_vec ();
-	  octave_idx_type nel = matrix.numel ();
-	  for (octave_idx_type i = 0; i < nel; i++)
-	    vec[i] = FloatComplex (matrix(i).float_value ());
-	}
+        {
+          retval = FloatComplexMatrix (dv(0), dv(1));
+          FloatComplex *vec = retval.fortran_vec ();
+          octave_idx_type nel = matrix.numel ();
+          for (octave_idx_type i = 0; i < nel; i++)
+            vec[i] = FloatComplex (matrix(i).float_value ());
+        }
       return retval;
     }
 
   NDArray
   array_value (bool = false) const
-    { 
-      NDArray retval (matrix.dims ()); 
+    {
+      NDArray retval (matrix.dims ());
       double *vec = retval.fortran_vec ();
       octave_idx_type nel = matrix.numel ();
       for (octave_idx_type i = 0; i < nel; i++)
@@ -237,8 +224,8 @@ public:
 
   FloatNDArray
   float_array_value (bool = false) const
-    { 
-      FloatNDArray retval (matrix.dims ()); 
+    {
+      FloatNDArray retval (matrix.dims ());
       float *vec = retval.fortran_vec ();
       octave_idx_type nel = matrix.numel ();
       for (octave_idx_type i = 0; i < nel; i++)
@@ -248,8 +235,8 @@ public:
 
   ComplexNDArray
   complex_array_value (bool = false) const
-    { 
-      ComplexNDArray retval (matrix.dims ()); 
+    {
+      ComplexNDArray retval (matrix.dims ());
       Complex *vec = retval.fortran_vec ();
       octave_idx_type nel = matrix.numel ();
       for (octave_idx_type i = 0; i < nel; i++)
@@ -259,8 +246,8 @@ public:
 
   FloatComplexNDArray
   float_complex_array_value (bool = false) const
-    { 
-      FloatComplexNDArray retval (matrix.dims ()); 
+    {
+      FloatComplexNDArray retval (matrix.dims ());
       FloatComplex *vec = retval.fortran_vec ();
       octave_idx_type nel = matrix.numel ();
       for (octave_idx_type i = 0; i < nel; i++)
@@ -291,7 +278,7 @@ public:
     charNDArray retval (dims ());
 
     octave_idx_type nel = numel ();
-  
+
     char *vec = retval.fortran_vec ();
     for (octave_idx_type i = 0; i < nel; i++)
       vec[i] = matrix(i).char_value ();
@@ -299,30 +286,34 @@ public:
     return retval;
   }
 
-  void increment (void) 
-   { 
-     matrix += OCTAVE_INT_T (1); 
-     if (OCTAVE_INT_T::get_math_trunc_flag ())
-       gripe_unop_integer_math_truncated ("++", type_name (). c_str ());
-
-      OCTAVE_INT_T::clear_conv_flag ();
+  // Use matrix_ref here to clear index cache.
+  void increment (void)
+   {
+     matrix_ref() += OCTAVE_INT_T (1);
    }
 
   void decrement (void)
-   { 
-     matrix -= OCTAVE_INT_T (1); 
-     if (OCTAVE_INT_T::get_math_trunc_flag ())
-       gripe_unop_integer_math_truncated ("--", type_name (). c_str ());
-      OCTAVE_INT_T::clear_conv_flag ();
+   {
+     matrix_ref() -= OCTAVE_INT_T (1);
    }
 
-  idx_vector index_vector (void) const { return idx_vector (matrix); }
+  void changesign (void)
+   {
+     matrix_ref ().changesign ();
+   }
+
+  idx_vector index_vector (void) const
+    { return idx_cache ? *idx_cache : set_idx_cache (idx_vector (matrix)); }
 
   int write (octave_stream& os, int block_size,
-	     oct_data_conv::data_type output_type, int skip,
-	     oct_mach_info::float_format flt_fmt) const
+             oct_data_conv::data_type output_type, int skip,
+             oct_mach_info::float_format flt_fmt) const
     { return os.write (matrix, block_size, output_type, skip, flt_fmt); }
 
+  // Unsafe.  This function exists to support the MEX interface.
+  // You should not use it anywhere else.
+  void *mex_get_data (void) const { return matrix.mex_get_data (); }
+
   mxArray *as_mxArray (void) const
   {
     mxArray *retval = new mxArray (OCTAVE_INT_MX_CLASS, dims (), mxREAL);
@@ -339,42 +330,37 @@ public:
     return retval;
   }
 
-#define MAT_MAPPER(FCN) \
-  octave_value FCN (void) const { return matrix.FCN (); }
+  octave_value map (unary_mapper_t umap) const
+    {
+      switch (umap)
+        {
+        case umap_abs:
+          return matrix.abs ();
+        case umap_signum:
+          return matrix.signum ();
+        case umap_ceil:
+        case umap_conj:
+        case umap_fix:
+        case umap_floor:
+        case umap_real:
+        case umap_round:
+          return matrix;
+        case umap_imag:
+          return intNDArray<OCTAVE_INT_T> (matrix.dims (), OCTAVE_INT_T ());
+        case umap_isnan:
+        case umap_isna:
+        case umap_isinf:
+          return boolNDArray (matrix.dims (), false);
+        case umap_finite:
+          return boolNDArray (matrix.dims (), true);
 
-  MAT_MAPPER (abs)
-  MAT_MAPPER (signum)
-
-#undef MAT_MAPPER
-
-  octave_value imag (void) const
-  {
-    return intNDArray<OCTAVE_INT_T> (matrix.dims (),
-				     static_cast<OCTAVE_INT_T>(0));
-  }
-
-#define NO_OP_MAPPER(FCN) \
-  octave_value FCN (void) const { return octave_value (matrix); }
-
-  NO_OP_MAPPER (ceil)
-  NO_OP_MAPPER (conj)
-  NO_OP_MAPPER (fix)
-  NO_OP_MAPPER (floor)
-  NO_OP_MAPPER (real)
-  NO_OP_MAPPER (round)
-  NO_OP_MAPPER (roundb)
-
-#undef NO_OP_MAPPER
-
-#define BOOL_MAPPER(FCN, VAL) \
-  octave_value FCN (void) const { return boolNDArray (matrix.dims (), VAL); }
-
-  BOOL_MAPPER (finite, true)
-  BOOL_MAPPER (isinf, false)
-  BOOL_MAPPER (isna, false)
-  BOOL_MAPPER (isnan, false)
-
-#undef BOOL_MAPPER
+        default:
+          {
+            octave_matrix m (array_value ());
+            return m.map (umap);
+          }
+        }
+    }
 
 private:
 
@@ -405,7 +391,7 @@ public:
     { return new OCTAVE_VALUE_INT_MATRIX_T (); }
 
   octave_value do_index_op (const octave_value_list& idx,
-			    bool resize_ok = false)
+                            bool resize_ok = false)
     {
       // FIXME -- this doesn't solve the problem of
       //
@@ -419,7 +405,7 @@ public:
 
       octave_value tmp
         (new OCTAVE_VALUE_INT_MATRIX_T
-         (OCTAVE_VALUE_INT_NDARRAY_EXTRACTOR_FUNCTION ())); 
+         (OCTAVE_VALUE_INT_NDARRAY_EXTRACTOR_FUNCTION ()));
 
       return tmp.do_index_op (idx, resize_ok);
     }
@@ -428,48 +414,33 @@ public:
 
   bool is_integer_type (void) const { return true; }
 
-private:
-
-  template <class IS>
-  IS convert_gripe () const
-    {
-      typedef IS dest_el_type;
-      typedef OCTAVE_INT_T src_el_type;
-      dest_el_type::clear_conv_flag ();
-      IS retval (scalar);
-
-      if (dest_el_type::get_trunc_flag ())
-	gripe_truncated_conversion (src_el_type::type_name (),
-				    dest_el_type::type_name ());
-      dest_el_type::clear_conv_flag ();
-      return retval;
-    }
+  builtin_type_t builtin_type (void) const { return OCTAVE_INT_BTYP; }
 
 public:
 
   octave_int8
-  int8_scalar_value (void) const { return convert_gripe<octave_int8> (); }
+  int8_scalar_value (void) const { return octave_int8 (scalar); }
 
   octave_int16
-  int16_scalar_value (void) const { return convert_gripe<octave_int16> (); }
+  int16_scalar_value (void) const { return octave_int16 (scalar); }
 
   octave_int32
-  int32_scalar_value (void) const { return convert_gripe<octave_int32> (); }
+  int32_scalar_value (void) const { return octave_int32 (scalar); }
 
   octave_int64
-  int64_scalar_value (void) const { return convert_gripe<octave_int64> (); }
+  int64_scalar_value (void) const { return octave_int64 (scalar); }
 
   octave_uint8
-  uint8_scalar_value (void) const { return convert_gripe<octave_uint8> (); }
+  uint8_scalar_value (void) const { return octave_uint8 (scalar); }
 
   octave_uint16
-  uint16_scalar_value (void) const { return convert_gripe<octave_uint16> (); }
+  uint16_scalar_value (void) const { return octave_uint16 (scalar); }
 
   octave_uint32
-  uint32_scalar_value (void) const { return convert_gripe<octave_uint32> (); }
+  uint32_scalar_value (void) const { return octave_uint32 (scalar); }
 
   octave_uint64
-  uint64_scalar_value (void) const { return convert_gripe<octave_uint64> (); }
+  uint64_scalar_value (void) const { return octave_uint64 (scalar); }
 
   int8NDArray
   int8_array_value (void) const
@@ -506,19 +477,19 @@ public:
   octave_value resize (const dim_vector& dv, bool fill = false) const
     {
       if (fill)
-	{
-	  intNDArray<OCTAVE_INT_T> retval (dv, 0);
-	  if (dv.numel())
-	    retval(0) = scalar;
-	  return retval;
-	}
+        {
+          intNDArray<OCTAVE_INT_T> retval (dv, 0);
+          if (dv.numel())
+            retval(0) = scalar;
+          return retval;
+        }
       else
-	{
-	  intNDArray<OCTAVE_INT_T> retval (dv);
-	  if (dv.numel())
-	    retval(0) = scalar;
-	  return retval;
-	}
+        {
+          intNDArray<OCTAVE_INT_T> retval (dv);
+          if (dv.numel())
+            retval(0) = scalar;
+          return retval;
+        }
     }
 
   double double_value (bool = false) const { return scalar.double_value (); }
@@ -563,23 +534,23 @@ public:
 
   NDArray
   array_value (bool = false) const
-    { 
-      NDArray retval (dim_vector (1, 1)); 
+    {
+      NDArray retval (dim_vector (1, 1));
       retval(0) = scalar.double_value ();
       return retval;
     }
 
   FloatNDArray
   float_array_value (bool = false) const
-    { 
-      FloatNDArray retval (dim_vector (1, 1)); 
+    {
+      FloatNDArray retval (dim_vector (1, 1));
       retval(0) = scalar.float_value ();
       return retval;
     }
 
   ComplexNDArray
   complex_array_value (bool = false) const
-    { 
+    {
       ComplexNDArray retval (dim_vector (1, 1));
       retval(0) = FloatComplex (scalar.double_value ());
       return retval;
@@ -587,12 +558,20 @@ public:
 
   FloatComplexNDArray
   float_complex_array_value (bool = false) const
-    { 
+    {
       FloatComplexNDArray retval (dim_vector (1, 1));
       retval(0) = FloatComplex (scalar.float_value ());
       return retval;
     }
 
+  bool bool_value (bool warn = false) const
+  {
+    if (warn && scalar != 0.0 && scalar != 1.0)
+      gripe_logical_conversion ();
+
+    return scalar.bool_value ();
+  }
+
   boolNDArray
   bool_array_value (bool warn = false) const
   {
@@ -614,30 +593,24 @@ public:
     return retval;
   }
 
-  void increment (void) 
-   { 
-     scalar += OCTAVE_INT_T (1); 
-     if (OCTAVE_INT_T::get_math_trunc_flag ())
-       gripe_unop_integer_math_truncated ("++", type_name (). c_str ());
-      OCTAVE_INT_T::clear_conv_flag ();
+  void increment (void)
+   {
+     scalar += OCTAVE_INT_T (1);
    }
 
   void decrement (void)
-   { 
-     scalar -= OCTAVE_INT_T (1); 
-     if (OCTAVE_INT_T::get_math_trunc_flag ())
-       gripe_unop_integer_math_truncated ("--", type_name (). c_str ());
-      OCTAVE_INT_T::clear_conv_flag ();
+   {
+     scalar -= OCTAVE_INT_T (1);
    }
 
   idx_vector index_vector (void) const { return idx_vector (scalar); }
 
   int write (octave_stream& os, int block_size,
-	     oct_data_conv::data_type output_type, octave_idx_type skip,
-	     oct_mach_info::float_format flt_fmt) const
+             oct_data_conv::data_type output_type, octave_idx_type skip,
+             oct_mach_info::float_format flt_fmt) const
     {
       return os.write (OCTAVE_VALUE_INT_NDARRAY_EXTRACTOR_FUNCTION (),
-		       block_size, output_type, skip, flt_fmt);
+                       block_size, output_type, skip, flt_fmt);
     }
 
   // Unsafe.  This function exists to support the MEX interface.
@@ -655,37 +628,37 @@ public:
     return retval;
   }
 
-#define SCALAR_MAPPER(FCN) \
-  octave_value FCN (void) const { return scalar.FCN (); }
+  octave_value map (unary_mapper_t umap) const
+    {
+      switch (umap)
+        {
+        case umap_abs:
+          return scalar.abs ();
+        case umap_signum:
+          return scalar.signum ();
+        case umap_ceil:
+        case umap_conj:
+        case umap_fix:
+        case umap_floor:
+        case umap_real:
+        case umap_round:
+          return scalar;
+        case umap_imag:
+          return OCTAVE_INT_T ();
+        case umap_isnan:
+        case umap_isna:
+        case umap_isinf:
+          return false;
+        case umap_finite:
+          return true;
 
-  SCALAR_MAPPER (abs)
-  SCALAR_MAPPER (signum)
-
-#undef SCALAR_MAPPER
-
-  octave_value imag (void) const { return static_cast<OCTAVE_INT_T>(0); }
-
-#define NO_OP_MAPPER(FCN) \
-  octave_value FCN (void) const { return octave_value (scalar); }
-
-  NO_OP_MAPPER (ceil)
-  NO_OP_MAPPER (conj)
-  NO_OP_MAPPER (fix)
-  NO_OP_MAPPER (floor)
-  NO_OP_MAPPER (real)
-  NO_OP_MAPPER (round)
-  NO_OP_MAPPER (roundb)
-
-#undef NO_OP_MAPPER
-
-#define BOOL_MAPPER(FCN, VAL) octave_value FCN (void) const { return VAL; }
-
-  BOOL_MAPPER (finite, true)
-  BOOL_MAPPER (isinf, false)
-  BOOL_MAPPER (isna, false)
-  BOOL_MAPPER (isnan, false)
-
-#undef BOOL_MAPPER
+        default:
+          {
+            octave_scalar m (scalar_value ());
+            return m.map (umap);
+          }
+        }
+    }
 
 private:
 
@@ -693,9 +666,3 @@ private:
 
   DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA
 };
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
