@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 1996, 1997, 1998, 1999, 2000, 2002, 2003, 2004, 2005,
-              2006, 2007 John W. Eaton
+Copyright (C) 1996-2012 John W. Eaton
+Copyright (C) 2009-2010 VZLU Prague
 
 This file is part of Octave.
 
@@ -26,7 +26,7 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <cstdlib>
 
-#include <iostream>
+#include <iosfwd>
 #include <string>
 
 #include "mx-base.h"
@@ -36,9 +36,9 @@ along with Octave; see the file COPYING.  If not, see
 #include "oct-stream.h"
 #include "ov.h"
 #include "ov-ch-mat.h"
+#include "ov-re-mat.h"
 #include "ov-typeinfo.h"
 
-class Octave_map;
 class octave_value_list;
 
 class tree_walker;
@@ -61,6 +61,9 @@ public:
   octave_char_matrix_str (const charNDArray& chm)
     : octave_char_matrix (chm) { }
 
+  octave_char_matrix_str (const Array<char>& chm)
+    : octave_char_matrix (chm) { }
+
   octave_char_matrix_str (char c)
     : octave_char_matrix (c) { }
 
@@ -84,32 +87,30 @@ public:
   octave_base_value *clone (void) const { return new octave_char_matrix_str (*this); }
   octave_base_value *empty_clone (void) const { return new octave_char_matrix_str (); }
 
-  type_conv_fcn numeric_conversion_function (void) const;
+  type_conv_info numeric_conversion_function (void) const;
 
   octave_value do_index_op (const octave_value_list& idx,
-			    bool resize_ok = false)
+                            bool resize_ok = false)
     { return do_index_op_internal (idx, resize_ok); }
 
-  void assign (const octave_value_list& idx, const charMatrix& rhs);
+  octave_value squeeze (void) const
+    { return octave_value (charNDArray (matrix.squeeze ())); }
 
   octave_value reshape (const dim_vector& new_dims) const
-    { return octave_value (charNDArray (matrix.reshape (new_dims)), true); }
+    { return octave_value (charNDArray (matrix.reshape (new_dims))); }
 
   octave_value permute (const Array<int>& vec, bool inv = false) const
-    { return octave_value (charNDArray (matrix.permute (vec, inv)), true); }
+    { return octave_value (charNDArray (matrix.permute (vec, inv))); }
 
   octave_value resize (const dim_vector& dv, bool fill = false) const;
 
+  octave_value diag (octave_idx_type k = 0) const
+    { return octave_value (matrix.diag (k)); }
+
   bool is_string (void) const { return true; }
 
-  bool is_real_type (void) const { return false; }
-
-  bool is_matrix_type (void) const { return false; }
-
   bool is_numeric_type (void) const { return false; }
 
-  bool valid_as_scalar_index (void) const;
-
   double double_value (bool = false) const;
 
   Matrix matrix_value (bool = false) const;
@@ -126,6 +127,15 @@ public:
 
   std::string string_value (bool force = false) const;
 
+  Array<std::string> cellstr_value (void) const;
+
+  octave_value sort (octave_idx_type dim = 0, sortmode mode = ASCENDING) const
+    { return octave_value (matrix.sort (dim, mode)); }
+
+  octave_value sort (Array<octave_idx_type> &sidx, octave_idx_type dim = 0,
+                     sortmode mode = ASCENDING) const
+    { return octave_value (matrix.sort (sidx, dim, mode)); }
+
   bool print_as_scalar (void) const { return (rows () <= 1); }
 
   void print_raw (std::ostream& os, bool pr_as_read_syntax = false) const;
@@ -136,24 +146,24 @@ public:
 
   bool save_binary (std::ostream& os, bool& save_as_floats);
 
-  bool load_binary (std::istream& is, bool swap, 
-		    oct_mach_info::float_format fmt);
+  bool load_binary (std::istream& is, bool swap,
+                    oct_mach_info::float_format fmt);
 
 #if defined (HAVE_HDF5)
   bool save_hdf5 (hid_t loc_id, const char *name, bool save_as_floats);
 
-  bool load_hdf5 (hid_t loc_id, const char *name, bool have_h5giterate_bug);
+  bool load_hdf5 (hid_t loc_id, const char *name);
 #endif
 
   int write (octave_stream& os, int block_size,
-	     oct_data_conv::data_type output_type, int skip,
-	     oct_mach_info::float_format flt_fmt) const
+             oct_data_conv::data_type output_type, int skip,
+             oct_mach_info::float_format flt_fmt) const
     { return os.write (matrix, block_size, output_type, skip, flt_fmt); }
 
 protected:
 
   octave_value do_index_op_internal (const octave_value_list& idx,
-				     bool resize_ok, char type = '"');
+                                     bool resize_ok, char type = '"');
 
 private:
 
@@ -178,6 +188,9 @@ public:
   octave_char_matrix_sq_str (const charNDArray& chm)
     : octave_char_matrix_str (chm) { }
 
+  octave_char_matrix_sq_str (const Array<char>& chm)
+    : octave_char_matrix_str (chm) { }
+
   octave_char_matrix_sq_str (char c)
     : octave_char_matrix_str (c) { }
 
@@ -201,25 +214,39 @@ public:
   octave_base_value *clone (void) const { return new octave_char_matrix_sq_str (*this); }
   octave_base_value *empty_clone (void) const { return new octave_char_matrix_sq_str (); }
 
+  octave_value squeeze (void) const
+    { return octave_value (charNDArray (matrix.squeeze ()), '\''); }
+
   octave_value reshape (const dim_vector& new_dims) const
-    { return octave_value (charNDArray (matrix.reshape (new_dims)), true, '\''); }
+    { return octave_value (charNDArray (matrix.reshape (new_dims)), '\''); }
 
   octave_value permute (const Array<int>& vec, bool inv = false) const
-    { return octave_value (charNDArray (matrix.permute (vec, inv)), true, '\''); }
+    { return octave_value (charNDArray (matrix.permute (vec, inv)), '\''); }
 
   octave_value resize (const dim_vector& dv, bool = false) const
     {
       charNDArray retval (matrix);
       retval.resize (dv);
-      return octave_value (retval, true, '\'');
+      return octave_value (retval, '\'');
     }
 
+  octave_value diag (octave_idx_type k = 0) const
+    { return octave_value (matrix.diag (k), '\''); }
+
   bool is_sq_string (void) const { return true; }
 
   octave_value do_index_op (const octave_value_list& idx,
-			    bool resize_ok = false)
+                            bool resize_ok = false)
     { return do_index_op_internal (idx, resize_ok, '\''); }
 
+
+  octave_value sort (octave_idx_type dim = 0, sortmode mode = ASCENDING) const
+    { return octave_value (matrix.sort (dim, mode), '\''); }
+
+  octave_value sort (Array<octave_idx_type> &sidx, octave_idx_type dim = 0,
+                     sortmode mode = ASCENDING) const
+    { return octave_value (matrix.sort (sidx, dim, mode), '\''); }
+
 private:
 
   DECLARE_OCTAVE_ALLOCATOR
@@ -228,9 +255,3 @@ private:
 };
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
