@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1996-2012 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -30,6 +29,7 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include "comment-list.h"
 #include "pt-walk.h"
 
+class tree_decl_command;
 class tree_expression;
 
 // How to print the code that the parse trees represent.
@@ -40,12 +40,12 @@ tree_print_code : public tree_walker
 public:
 
   tree_print_code (std::ostream& os_arg,
-		   const std::string& pfx = std::string (),
-		   bool pr_orig_txt = true)
+                   const std::string& pfx = std::string (),
+                   bool pr_orig_txt = true)
     : os (os_arg), prefix (pfx), nesting (),
       print_original_text (pr_orig_txt),
       curr_print_indent_level (0), beginning_of_line (true),
-      printing_newlines (true)
+      suppress_newlines (0)
   {
     // For "none".
     nesting.push ('n');
@@ -65,7 +65,9 @@ public:
 
   void visit_continue_command (tree_continue_command&);
 
-  void visit_decl_command (tree_decl_command&);
+  void visit_global_command (tree_global_command&);
+
+  void visit_static_command (tree_static_command&);
 
   void visit_decl_elt (tree_decl_elt&);
 
@@ -75,12 +77,16 @@ public:
 
   void visit_complex_for_command (tree_complex_for_command&);
 
+  void visit_octave_user_script (octave_user_script&);
+
   void visit_octave_user_function (octave_user_function&);
 
   void visit_octave_user_function_header (octave_user_function&);
 
   void visit_octave_user_function_trailer (octave_user_function&);
 
+  void visit_function_def (tree_function_def&);
+
   void visit_identifier (tree_identifier&);
 
   void visit_if_clause (tree_if_clause&);
@@ -133,9 +139,7 @@ public:
 
   void visit_do_until_command (tree_do_until_command&);
 
-  void suspend_newline (void) { printing_newlines = false; }
-
-  void resume_newline (void) { printing_newlines = true; }
+  void print_fcn_handle_body (tree_statement_list *);
 
 private:
 
@@ -153,8 +157,10 @@ private:
   // TRUE means we are at the beginning of a line.
   bool beginning_of_line;
 
-  // TRUE means we are printing newlines and indenting.
-  bool printing_newlines;
+  // Nonzero means we are not printing newlines and indenting.
+  int suppress_newlines;
+
+  void do_decl_command (tree_decl_command& cmd);
 
   void reset_indent_level (void) { curr_print_indent_level = 0; }
 
@@ -188,9 +194,3 @@ private:
 };
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
